##############################################################################
#
# MODULE:       r.slope.stability.install.sh
#
# AUTHORS:      Martin Mergili, Andreas Huber and Jan-Thomas Fischer
#
# PURPOSE:      The slope stability model - Installation script
#
# COPYRIGHT:    (c) 2009 - 2016 by the authors
#               (c) 2009 - 2016 by the BOKU University, Vienna
#               (c) 2015 - 2016 by the University of Vienna
#               (c) 2016        by the BFW, Innsbruck
#               (c) 2000 - 2016 by the GRASS Development Team
#
# VERSION:      20161205 (5 December 2016)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


echo ""

pathmain=`pwd`

PATHGRASS="/usr/lib/grass70/"
PATHPYTHON="/usr/lib/python2.7/"
PATHDOCS="/usr/share/doc/grass-doc/html/"

#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts
cp r.slope.stability.evolution.r "$PATHGRASS"scripts/r.slope.stability.evolution.r
cp r.slope.stability.map.r "$PATHGRASS"scripts/r.slope.stability.map.r
cp r.slope.stability.profile.r "$PATHGRASS"scripts/r.slope.stability.profile.r
cp r.slope.stability.rad.r "$PATHGRASS"scripts/r.slope.stability.rad.r
cp r.slope.stability.reg.r "$PATHGRASS"scripts/r.slope.stability.reg.r
cp r.slope.stability.roc.r "$PATHGRASS"scripts/r.slope.stability.roc.r

#Installing Python scripts
cp r.slope.stability.py "$PATHGRASS"scripts/r.slope.stability
chmod +x "$PATHGRASS"scripts/r.slope.stability
cp r.slope.stability.mult.py "$PATHGRASS"scripts/r.slope.stability.mult
chmod +x "$PATHGRASS"scripts/r.slope.stability.mult

#Installing manual
cp r.slope.stability.html "$PATHDOCS"

#Returning to initial directory
cd $pathmain

#Installing C script r.slope.stability.main.c
#Creating directory for raster module
if [ ! -d "$PATHGRASS"raster ]
then
    mkdir "$PATHGRASS"raster
fi

#Removing directory with installation files, if existing
if [ -d "$PATHGRASS"raster/r.slope.stability.main ]
then
    rm -rf "$PATHGRASS"raster/r.slope.stability.main
fi

if [ -f "$PATHGRASS"bin/r.slope.stability.main ]
then
    rm "$PATHGRASS"bin/r.slope.stability.main
fi

#Creating directory for installation files and copying r.slope.stability.main.c
mkdir "$PATHGRASS"raster/r.slope.stability.main
cp r.slope.stability.main.c "$PATHGRASS"raster/r.slope.stability.main/main.c
cp r.slope.stability.html "$PATHDOCS"/r.slope.stability.main.html

#Moving to the directory for installation files
cd "$PATHGRASS"raster/r.slope.stability.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile
echo "CFLAGS = -w" >> Makefile

# Installing r.slope.stability.main
INST_NOW=y make

echo ""
echo "Installation completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear

